@@ -6,16 +6,17 @@ def CreateFile(name, ifexists = False):
     f = None
     if ifexists:
         if not os.path.exists(name):
-            f = open(name, 'w+')
+            f = open(name, 'x')
     else:
-        f = open(name, 'w+')
+        f = open(name, 'x')
     return f
 
 def DeleteFile(name):
+    # os.remove(name)
     if os.path.exists(name):
         os.remove(name)
     else:
-        print("\033[91m", "The file does not exist", "\033[0m")
+        print("\033[91m" + "The file does not exist" + "\033[0m")
     
 def ReadFile(name):
     f = open(name, 'r')
@@ -45,4 +46,28 @@ def AppendFile(name, text):
     
 def CheckFileExists(name):
     exists = os.path.exists(name)
-    return exists
\ No newline at end of file
+    return exists
+
+def Create(name, ifexists = False):
+    return CreateFile(name, ifexists)
+
+def Delete(name):
+    DeleteFile(name)
+    
+def Read(name):
+    return ReadFile(name)
+
+def ReadLines(name):
+    return ReadFileLines(name)
+
+def ReadLine(name, line):
+    return ReadFileLine(name, line)
+
+def Write(name, text):
+    return WriteFile(name, text)
+    
+def Append(name, text):
+    return AppendFile(name, text)
+    
+def CheckExists(name):
+    return CheckFileExists(name)
\ No newline at end of file
